module Fog
  module ARM
    module Storage
      module Models
        module Kind
          Storage = 'Storage'.freeze
          BlobStorage = 'BlobStorage'.freeze
        end
      end
    end
  end
end
