module Fog
  module ARM
    module Storage
      module Models
        module SkuName
          StandardLRS = 'Standard_LRS'.freeze
          StandardGRS = 'Standard_GRS'.freeze
          StandardRAGRS = 'Standard_RAGRS'.freeze
          StandardZRS = 'Standard_ZRS'.freeze
          PremiumLRS = 'Premium_LRS'.freeze
        end
      end
    end
  end
end
