module Fog
  module ARM
    module Storage
      module Models
        module SkuTier
          Standard = 'Standard'.freeze
          Premium = 'Premium'.freeze
        end
      end
    end
  end
end
